==> apache-camel-4.10.8-src.zip: apache-camel-4.10.8/core/camel-management-api/src/main/java/org/apache/camel/api/management/mbean/ManagedPollMBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.api.management.mbean;

import javax.management.openmbean.TabularData;

import org.apache.camel.api.management.ManagedAttribute;
import org.apache.camel.api.management.ManagedOperation;

public interface ManagedPollMBean extends ManagedProcessorMBean, ManagedExtendedInformation {

    @ManagedAttribute(description = "Destination as Endpoint URI",
                      mask = true)
    String getDestination();

    @ManagedAttribute(description = "Variable to store the received message body (only body, not headers)")
    String getVariableReceive();

    @ManagedAttribute(description = "Timeout in millis when polling from the external service")
    Long getTimeout();

    @Override
    @ManagedOperation(description = "Statistics of the endpoints that has been poll enriched from")
    TabularData extendedInformation();

}

==> apache-camel-4.16.0-src.zip: apache-camel-4.16.0/core/camel-management-api/src/main/java/org/apache/camel/api/management/mbean/ManagedPollMBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.api.management.mbean;

import javax.management.openmbean.TabularData;

import org.apache.camel.api.management.ManagedAttribute;
import org.apache.camel.api.management.ManagedOperation;

public interface ManagedPollMBean extends ManagedProcessorMBean, ManagedExtendedInformation, ManagedDestinationAware {

    @ManagedAttribute(description = "Destination as Endpoint URI",
                      mask = true)
    String getDestination();

    @ManagedAttribute(description = "Variable to store the received message body (only body, not headers)")
    String getVariableReceive();

    @ManagedAttribute(description = "Timeout in millis when polling from the external service")
    Long getTimeout();

    @Override
    @ManagedOperation(description = "Statistics of the endpoints that has been poll enriched from")
    TabularData extendedInformation();

}
